import { objectWithoutProperties as _objectWithoutProperties, extends as _extends } from '../../_virtual/_rollupPluginBabelHelpers.js';
import _ from 'lodash';
import React, { forwardRef, useRef, useCallback } from 'react';
import Animated, { FadeIn, LinearTransition } from 'react-native-reanimated';
import Frame from '../placeholders/frame/index.js';
import Empty from './empty/index.js';
import Footer from './footer/index.js';

var _excluded = ["data", "EmptyComponent", "PlaceholderComponent", "emptyListTitle", "emptyListText", "emptyListImg", "onEndReached", "onEndReachedAsync", "placeholderCount", "placeholderContainerStyle", "totalEntities", "hasLayoutAnimation", "isFetching", "isFirstRender", "initialNumToRender"];
/**
 * Flat list wrapper
 */
var FlatList = function FlatList(_ref, ref) {
  var _data$length;
  var data = _ref.data,
    EmptyComponent = _ref.EmptyComponent,
    PlaceholderComponent = _ref.PlaceholderComponent,
    emptyListTitle = _ref.emptyListTitle,
    emptyListText = _ref.emptyListText,
    emptyListImg = _ref.emptyListImg,
    onEndReached = _ref.onEndReached,
    onEndReachedAsync = _ref.onEndReachedAsync,
    placeholderCount = _ref.placeholderCount,
    placeholderContainerStyle = _ref.placeholderContainerStyle,
    _ref$totalEntities = _ref.totalEntities,
    totalEntities = _ref$totalEntities === void 0 ? 0 : _ref$totalEntities,
    _ref$hasLayoutAnimati = _ref.hasLayoutAnimation,
    hasLayoutAnimation = _ref$hasLayoutAnimati === void 0 ? true : _ref$hasLayoutAnimati,
    _ref$isFetching = _ref.isFetching,
    isFetching = _ref$isFetching === void 0 ? false : _ref$isFetching,
    _ref$isFirstRender = _ref.isFirstRender,
    isFirstRender = _ref$isFirstRender === void 0 ? false : _ref$isFirstRender,
    _ref$initialNumToRend = _ref.initialNumToRender,
    initialNumToRender = _ref$initialNumToRend === void 0 ? 5 : _ref$initialNumToRend,
    props = _objectWithoutProperties(_ref, _excluded);
  var length = (_data$length = data === null || data === void 0 ? void 0 : data['length']) !== null && _data$length !== void 0 ? _data$length : 0;
  var hasRows = length > 0;
  var onEndReachedCalledDuringMomentum = useRef(true);
  /**
   * User touch list (e.g. little scroll)
   * Prevent call onEndReached on first render
   */
  var onMomentumScrollBegin = useCallback(function () {
    onEndReachedCalledDuringMomentum.current = false;
  }, []);
  /**
   * Handle onEndReached
   * Prevent call multiple times
   */
  var onEndReachedThrottled = useCallback(_.throttle(function (params) {
    if (!onEndReachedCalledDuringMomentum.current && (onEndReached || onEndReachedAsync)) {
      onEndReachedCalledDuringMomentum.current = true;
      if (onEndReachedAsync) {
        void onEndReachedAsync();
      } else if (onEndReached) {
        onEndReached(params);
      }
    }
  }, 1000, {
    trailing: false
  }), []);
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Frame, {
    count: placeholderCount !== null && placeholderCount !== void 0 ? placeholderCount : initialNumToRender,
    isFetching: isFetching,
    isFirstRender: isFirstRender,
    containerStyle: placeholderContainerStyle,
    PlaceholderComponent: PlaceholderComponent
  }), !isFirstRender && /*#__PURE__*/React.createElement(Animated.FlatList, _extends({
    ref: ref,
    data: data,
    refreshing: isFetching,
    initialNumToRender: initialNumToRender,
    onEndReachedThreshold: 0.5,
    showsVerticalScrollIndicator: false
  }, hasLayoutAnimation ? {
    entering: FadeIn,
    layout: LinearTransition.duration(300)
  } : {}, {
    onScrollBeginDrag: onMomentumScrollBegin,
    onEndReached: onEndReachedThrottled,
    ListFooterComponent: totalEntities > initialNumToRender && /*#__PURE__*/React.createElement(Footer, {
      hasRows: hasRows,
      isFetching: isFetching
    }) || undefined,
    ListEmptyComponent: EmptyComponent || EmptyComponent !== false && /*#__PURE__*/React.createElement(Empty, {
      hasRows: hasRows,
      isFetching: isFetching,
      title: emptyListTitle,
      text: emptyListText,
      Img: emptyListImg
    }) || undefined
  }, props)));
};
var index = /*#__PURE__*/forwardRef(FlatList);

export { index as default };
//# sourceMappingURL=index.js.map
