import { slicedToArray as _slicedToArray, objectWithoutProperties as _objectWithoutProperties, extends as _extends } from '../../_virtual/_rollupPluginBabelHelpers.js';
import React, { useState, useRef, useEffect } from 'react';
import { Animated } from 'react-native';
import FastImage from 'react-native-fast-image';
import Animated$1, { useSharedValue, useDerivedValue, withTiming, interpolateColor, useAnimatedProps } from 'react-native-reanimated';
import Svg, { Circle } from 'react-native-svg';
import Loader from '../loader/index.js';
import styles from './styles.js';

var _excluded = ["style"],
  _excluded2 = ["style"],
  _excluded3 = ["style"];
var AnimatedFastImage = Animated.createAnimatedComponent(FastImage);
var AnimatedCircle = Animated$1.createAnimatedComponent(Circle);
var radius = 45;
var circumference = radius * Math.PI * 2;
var duration = 1000;
/**
 * Render progressive image
 * @constructor
 */
var ProgressiveImage = function ProgressiveImage(_ref) {
  var source = _ref.source,
    thumbnailSource = _ref.thumbnailSource,
    style = _ref.style,
    _ref$sourceProps = _ref.sourceProps,
    sourceProps = _ref$sourceProps === void 0 ? {} : _ref$sourceProps,
    _ref$thumbnailProps = _ref.thumbnailProps,
    thumbnailProps = _ref$thumbnailProps === void 0 ? {} : _ref$thumbnailProps,
    _ref$fastProps = _ref.fastProps,
    fastProps = _ref$fastProps === void 0 ? {} : _ref$fastProps,
    _ref$progressProps = _ref.progressProps,
    progressProps = _ref$progressProps === void 0 ? {} : _ref$progressProps,
    _ref$progressCirclePr = _ref.progressCircleProps,
    progressCircleProps = _ref$progressCirclePr === void 0 ? {} : _ref$progressCirclePr,
    _ref$priority = _ref.priority,
    priority = _ref$priority === void 0 ? FastImage.priority.normal : _ref$priority,
    _ref$loaderProps = _ref.loaderProps,
    loaderProps = _ref$loaderProps === void 0 ? {} : _ref$loaderProps,
    _ref$isFastImg = _ref.isFastImg,
    isFastImg = _ref$isFastImg === void 0 ? false : _ref$isFastImg,
    _ref$hasIndicator = _ref.hasIndicator,
    hasIndicator = _ref$hasIndicator === void 0 ? true : _ref$hasIndicator,
    _ref$hasProgress = _ref.hasProgress,
    hasProgress = _ref$hasProgress === void 0 ? true : _ref$hasProgress;
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    isThumbnailLoaded = _useState2[0],
    setIsThumbnailLoaded = _useState2[1];
  var _useState3 = useState(false),
    _useState4 = _slicedToArray(_useState3, 2),
    isSourceLoaded = _useState4[0],
    setIsSourceLoaded = _useState4[1];
  var _useState5 = useState(false),
    _useState6 = _slicedToArray(_useState5, 2),
    hasPassedDelay = _useState6[0],
    setHasPassedDelay = _useState6[1];
  var _useState7 = useState(new Animated.Value(0)),
    _useState8 = _slicedToArray(_useState7, 1),
    sourceAnim = _useState8[0];
  var _useState9 = useState(new Animated.Value(0)),
    _useState10 = _slicedToArray(_useState9, 1),
    thumbnailAnim = _useState10[0];
  var timerProgressId = useRef();
  useEffect(function () {
    if (!hasProgress) {
      return;
    }
    /**
     * Delay showing the progress
     */
    timerProgressId.current = setTimeout(function () {
      setHasPassedDelay(true);
    }, 2000);
    return function () {
      clearTimeout(timerProgressId.current);
    };
  }, []);
  /**
   * Circle animation
   * https://medium.com/react-native-rocket/animating-progress-rings-with-react-native-reanimated-2-9c19ad2115b
   */
  var strokeOffset = useSharedValue(circumference - 1);
  var percentage = useDerivedValue(function () {
    var number = (circumference - strokeOffset.value) / circumference * 100;
    return withTiming(number, {
      duration: duration
    });
  });
  var strokeColor = useDerivedValue(function () {
    return interpolateColor(percentage.value, [0, 50, 100], ['rgb(255,246,247)', 'rgba(246, 246, 89, 1)', 'rgba(79, 246, 89, 0.3)']);
  });
  var animatedCircleProps = useAnimatedProps(function () {
    return {
      strokeDashoffset: withTiming(strokeOffset.value, {
        duration: duration
      }),
      stroke: strokeColor.value
    };
  });
  /**
   * Change animated value to visible thumbnail image
   */
  var onThumbnailLoad = function onThumbnailLoad() {
    Animated.timing(thumbnailAnim, {
      toValue: 1,
      useNativeDriver: false
    }).start();
    setIsThumbnailLoaded(true);
  };
  /**
   * Change animated value to visible source image
   */
  var onSourceLoad = function onSourceLoad() {
    Animated.timing(sourceAnim, {
      toValue: 1,
      useNativeDriver: false
    }).start(function () {
      clearTimeout(timerProgressId.current);
      setIsSourceLoaded(true);
    });
  };
  /**
   * Source image progress load
   */
  var onProgressSourceLoad = function onProgressSourceLoad(_ref2) {
    var _ref2$nativeEvent = _ref2.nativeEvent,
      total = _ref2$nativeEvent.total,
      loaded = _ref2$nativeEvent.loaded;
    if (!hasProgress) {
      return;
    }
    var loadPercent = Math.round(loaded / total * 100);
    // load progress
    strokeOffset.value = circumference - circumference * loadPercent / 100;
  };
  var sourceStyle = sourceProps.style,
    otherSourceProps = _objectWithoutProperties(sourceProps, _excluded);
  var thumbnailStyle = thumbnailProps.style,
    otherThumbnailProps = _objectWithoutProperties(thumbnailProps, _excluded2);
  var loaderStyle = loaderProps.style,
    otherLoaderProps = _objectWithoutProperties(loaderProps, _excluded3);
  var isDisplayLoader = hasIndicator && !isThumbnailLoaded && !isSourceLoaded;
  var isDisplayProgress = hasProgress && hasPassedDelay && !isDisplayLoader && !isSourceLoaded;
  var isDisplayThumbnail = thumbnailSource && !isSourceLoaded;
  var isDisplaySource = isThumbnailLoaded || !thumbnailSource || isSourceLoaded;
  return /*#__PURE__*/React.createElement(React.Fragment, null, isDisplayLoader && /*#__PURE__*/React.createElement(Loader, _extends({}, otherLoaderProps, {
    style: [styles.overlay, loaderStyle]
  })), isDisplayProgress && /*#__PURE__*/React.createElement(Svg, _extends({
    style: styles.overlay,
    height: "100%",
    width: "100%",
    viewBox: "-75 -25 250 250"
  }, progressProps), /*#__PURE__*/React.createElement(AnimatedCircle, _extends({
    cx: "50",
    cy: "50",
    r: "45",
    stroke: "rgb(246, 79, 89)",
    strokeWidth: "3",
    fill: "rgba(255,255,255,0.05)"
  }, progressCircleProps, {
    animatedProps: animatedCircleProps,
    strokeDasharray: circumference
  }))), isDisplayThumbnail && isFastImg ? /*#__PURE__*/React.createElement(AnimatedFastImage, _extends({}, typeof thumbnailSource === 'string' ? {
    source: {
      uri: thumbnailSource,
      priority: priority,
      cache: FastImage.cacheControl.immutable
    }
  } : {}, fastProps, {
    // @ts-ignore
    style: [style, thumbnailStyle, {
      opacity: thumbnailAnim
    }],
    onLoad: onThumbnailLoad
  })) : isDisplayThumbnail && /*#__PURE__*/React.createElement(Animated.Image, _extends({
    blurRadius: 2
  }, otherThumbnailProps, {
    source: typeof thumbnailSource === 'string' ? {
      uri: thumbnailSource
    } : thumbnailSource,
    style: [style, thumbnailStyle, {
      opacity: thumbnailAnim
    }],
    onLoad: onThumbnailLoad
  })), isDisplaySource && isFastImg ? /*#__PURE__*/React.createElement(AnimatedFastImage, _extends({}, typeof source === 'string' ? {
    source: {
      uri: source,
      priority: priority,
      cache: FastImage.cacheControl.immutable
    }
  } : {}, fastProps, {
    // @ts-ignore
    style: [styles.overlay, style, sourceStyle, {
      opacity: sourceAnim
    }],
    onLoad: onSourceLoad,
    onProgress: onProgressSourceLoad
  })) : isDisplaySource && /*#__PURE__*/React.createElement(Animated.Image, _extends({}, otherSourceProps, {
    source: typeof source === 'string' ? {
      uri: source
    } : source,
    style: [styles.overlay, style, sourceStyle, {
      opacity: sourceAnim
    }],
    onLoad: onSourceLoad,
    onProgress: onProgressSourceLoad
  })));
};

export { ProgressiveImage as default };
//# sourceMappingURL=index.js.map
