import { slicedToArray as _slicedToArray } from '../_virtual/_rollupPluginBabelHelpers.js';
import { NativeModules } from 'react-native';
import { ArgType } from 'reactotron-core-client';
import Reactotron from 'reactotron-react-native';
import MobxStoreManagerPlugin from '@lomray/reactotron-mobx-store-manager';

/**
 * Init reactotron
 */
var init = function init(_ref) {
  var _reactotron$setAsyncS, _reactotron$clear;
  var isDebug = _ref.isDebug,
    AsyncStorage = _ref.AsyncStorage,
    _ref$isTests = _ref.isTests,
    isTests = _ref$isTests === void 0 ? false : _ref$isTests;
  if (isTests) {
    return {};
  }
  if (isDebug) {
    // @ts-ignore
    console.log = Reactotron.log; // for console.log in reactotron
    // For working on physic device
    var scriptURL = NativeModules.SourceCode.scriptURL || '';
    var domain = scriptURL.split('://')[1];
    if (domain) {
      Reactotron.configure({
        host: domain.split(':')[0]
      });
    }
  }
  var reactotron = Reactotron.configure().useReactNative({
    networking: {
      ignoreUrls: /(https:\/\/clients3.google.com\/generate_204)/
    }
  }).use(MobxStoreManagerPlugin()).connect(); // let's connect!
  (_reactotron$setAsyncS = reactotron.setAsyncStorageHandler) === null || _reactotron$setAsyncS === void 0 || _reactotron$setAsyncS.call(reactotron, AsyncStorage); // AsyncStorage would either come from `react-native` or `@react-native-community/async-storage` depending on where you get it from
  // print async storage
  reactotron.onCustomCommand({
    command: 'showAsyncStorage',
    handler: function handler() {
      AsyncStorage.getAllKeys(function (_, keys) {
        AsyncStorage.multiGet(keys, function (__, stores) {
          var _reactotron$logImport;
          var result = {};
          stores.map(function (___, i, store) {
            var _store$i = _slicedToArray(store[i], 2),
              n = _store$i[0],
              v = _store$i[1];
            result[n] = v;
            result["----".concat(i, "----")] = '-----------';
            return true;
          });
          (_reactotron$logImport = reactotron.logImportant) === null || _reactotron$logImport === void 0 || _reactotron$logImport.call(reactotron, result);
        });
      });
    },
    title: 'Show AsyncStorage',
    description: 'Print async storage content'
  });
  // remove key from async storage
  reactotron.onCustomCommand({
    command: 'removeKeyAsyncStorage',
    handler: function handler(_ref2) {
      var key = _ref2.key;
      AsyncStorage.removeItem(key).then(function () {
        var _reactotron$logImport2;
        (_reactotron$logImport2 = reactotron.logImportant) === null || _reactotron$logImport2 === void 0 || _reactotron$logImport2.call(reactotron, "Key ".concat(key, " removed!"));
      });
    },
    args: [{
      name: 'key',
      type: ArgType.String
    }],
    title: 'Remove key AsyncStorage',
    description: 'Remove key from async storage'
  });
  // reset timeline
  (_reactotron$clear = reactotron.clear) === null || _reactotron$clear === void 0 || _reactotron$clear.call(reactotron);
  return reactotron;
};

export { init as default };
//# sourceMappingURL=reactotron-config.js.map
