import _ from 'lodash';
import { Linking, Alert } from 'react-native';
import { showTopFlashMessage } from '../components/top-flash-messages/index.js';
import Config from '../services/config.js';
import customI18n from '../services/localization.js';
import VersionCheck from '../services/version-check.js';

/**
 * Check app version and show dialog for update
 */
var checkNewVersion = _.debounce(function (params) {
  var _ref = params !== null && params !== void 0 ? params : {},
    _ref$countryCode = _ref.countryCode,
    countryCode = _ref$countryCode === void 0 ? 'us' : _ref$countryCode,
    _ref$isMandatoryUpdat = _ref.isMandatoryUpdate,
    isMandatoryUpdate = _ref$isMandatoryUpdat === void 0 ? false : _ref$isMandatoryUpdat;
  var isDev = !Config.get('isProdDeployment');
  var packageName = Config.get('packageName');
  var logger = Config.get('logger');
  if (isDev || !packageName) {
    return;
  }
  VersionCheck.init({
    bundleId: packageName,
    countryCode: countryCode
  }).needUpdate().then(function (_ref2) {
    var hasUpdate = _ref2.hasUpdate,
      storeUrl = _ref2.storeUrl;
    if (!hasUpdate) {
      return;
    }
    var buttons = [{
      text: customI18n.t('translation:cancel'),
      style: 'cancel'
    }, {
      text: customI18n.t('translation:update'),
      onPress: function onPress() {
        Linking.canOpenURL(storeUrl).then(function (supported) {
          if (!supported) {
            return;
          }
          void Linking.openURL(storeUrl);
        }, function (err) {
          return showTopFlashMessage({
            message: customI18n.t('translation:error'),
            description: err,
            type: 'danger'
          });
        });
      }
    }];
    Alert.alert(customI18n.t('translation:alertTitle'), customI18n.t('translation:alertMessage'), isMandatoryUpdate ? [buttons[1]] : buttons, {
      cancelable: false
    });
  })["catch"](function (e) {
    logger === null || logger === void 0 || logger.error('Failed check store version #1: ', e);
  });
}, 30000, {
  leading: true,
  trailing: false
});

export { checkNewVersion as default };
//# sourceMappingURL=check-new-version.js.map
