import { useRef, useEffect } from 'react';
import { Navigation } from 'react-native-navigation';

/**
 * Called each time when component appears on screen (attached to the view hierarchy)
 */
var useNavDidAppear = function useNavDidAppear(handler, options) {
  var disappearCallback = useRef();
  var onceAppearFired = useRef(false);
  var _options$isRepeat = options.isRepeat,
    isRepeat = _options$isRepeat === void 0 ? false : _options$isRepeat;
  /**
   * Did appear
   */
  useEffect(function () {
    var subscription = Navigation.events().registerComponentDidAppearListener(function (event) {
      var componentId = event.componentId,
        componentName = event.componentName;
      if ('componentId' in options && options.componentId !== componentId || 'componentName' in options && options.componentName !== componentName) {
        return;
      }
      if (!isRepeat && onceAppearFired.current) {
        return;
      }
      disappearCallback.current = handler(event);
      onceAppearFired.current = true;
    });
    return function () {
      return subscription.remove();
    };
  }, [handler, options]);
  /**
   * Did disappear
   */
  useEffect(function () {
    var subscription = Navigation.events().registerComponentDidDisappearListener(function (event) {
      var _disappearCallback$cu;
      var componentId = event.componentId,
        componentName = event.componentName;
      if ('componentId' in options && options.componentId !== componentId || 'componentName' in options && options.componentName !== componentName) {
        return;
      }
      (_disappearCallback$cu = disappearCallback.current) === null || _disappearCallback$cu === void 0 || _disappearCallback$cu.call(disappearCallback, event);
      if (!isRepeat && disappearCallback.current) {
        disappearCallback.current = undefined;
      }
    });
    return function () {
      return subscription.remove();
    };
  }, [handler, options]);
};

export { useNavDidAppear as default };
//# sourceMappingURL=use-nav-did-appear.js.map
