import { objectSpread2 as _objectSpread2, extends as _extends } from '../../_virtual/_rollupPluginBabelHelpers.js';
import React, { useRef, useCallback, useEffect } from 'react';
import { Dimensions, Animated, PanResponder, View } from 'react-native';
import PressHandler from '../../components/press-handler/index.js';
import { closeHalfBottom } from './control.js';
import styles from './styles.js';

/**
 * Animation time setting
 */
var CLOSING_TIME = 200;
var STEP_BOUNCE_TIME = 150;
var OPENING_BACKGROUND_TIME = 300;
/**
 * Modal container
 * @constructor
 */
var BottomHalfContainer = function BottomHalfContainer(_ref) {
  var id = _ref.id,
    children = _ref.children,
    height = _ref.height,
    onClose = _ref.onClose,
    containerStyle = _ref.containerStyle,
    dropdownStyle = _ref.dropdownStyle,
    pressHandlerStyle = _ref.pressHandlerStyle,
    controlButtonContainerStyle = _ref.controlButtonContainerStyle,
    controlButtonStyle = _ref.controlButtonStyle,
    _ref$hasControlButton = _ref.hasControlButton,
    hasControlButton = _ref$hasControlButton === void 0 ? true : _ref$hasControlButton,
    _ref$shouldClose = _ref.shouldClose,
    shouldClose = _ref$shouldClose === void 0 ? false : _ref$shouldClose;
  var screenHeight = Dimensions.get('screen').height;
  var panY = useRef(new Animated.Value(screenHeight)).current;
  var fadeAnim = useRef(new Animated.Value(0)).current;
  /**
   * Bounce effect setting
   */
  var resetPositionAnim = function resetPositionAnim() {
    return Animated.sequence([Animated.timing(panY, {
      toValue: 0,
      duration: STEP_BOUNCE_TIME,
      useNativeDriver: true
    }), Animated.timing(panY, {
      toValue: 20,
      duration: STEP_BOUNCE_TIME,
      useNativeDriver: true
    }), Animated.timing(panY, {
      toValue: 0,
      duration: STEP_BOUNCE_TIME,
      useNativeDriver: true
    })]).start();
  };
  /**
   * Opacity of the effect when opening the modal
   */
  var openAnim = Animated.timing(fadeAnim, {
    toValue: 1,
    duration: OPENING_BACKGROUND_TIME,
    useNativeDriver: true
  });
  var closeAnim = function closeAnim() {
    Animated.parallel([Animated.timing(panY, {
      toValue: 700,
      duration: CLOSING_TIME,
      useNativeDriver: true
    }), Animated.timing(fadeAnim, {
      toValue: 0,
      duration: CLOSING_TIME,
      useNativeDriver: true
    })]).start();
  };
  var translateY = panY.interpolate({
    inputRange: [-1, 0, 1],
    outputRange: [0, 0, 1]
  });
  /**
   * Close modal by clicking on overlay
   */
  var handleDismiss = useCallback(function () {
    closeAnim();
    setTimeout(function () {
      void closeHalfBottom(id);
      onClose === null || onClose === void 0 || onClose();
    }, CLOSING_TIME);
  }, [closeAnim]);
  /**
   * Show modal
   */
  useEffect(function () {
    resetPositionAnim();
    openAnim.start();
  }, []);
  /**
   * Close modal
   */
  useEffect(function () {
    if (!shouldClose) {
      return;
    }
    handleDismiss();
  }, [shouldClose]);
  var panResponders = useRef(PanResponder.create({
    onStartShouldSetPanResponder: function onStartShouldSetPanResponder() {
      return true;
    },
    onMoveShouldSetPanResponder: function onMoveShouldSetPanResponder() {
      return false;
    },
    onPanResponderMove: Animated.event([null, {
      dy: panY
    }], {
      useNativeDriver: false
    }),
    onPanResponderRelease: function onPanResponderRelease(_, gs) {
      if (gs.dy > 0 && gs.vy > 1) {
        return onClose === null || onClose === void 0 ? void 0 : onClose();
      }
      return resetPositionAnim();
    }
  })).current;
  return /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.container, containerStyle, {
      opacity: fadeAnim
    }]
  }, /*#__PURE__*/React.createElement(PressHandler, {
    style: [styles.wrapper, pressHandlerStyle],
    onPress: onClose
  }), /*#__PURE__*/React.createElement(Animated.View, {
    style: [_objectSpread2(_objectSpread2({}, styles.dropdown), {}, {
      transform: [{
        translateY: translateY
      }]
    }), dropdownStyle, height && {
      height: height
    } || undefined]
  }, hasControlButton && /*#__PURE__*/React.createElement(Animated.View, _extends({}, panResponders.panHandlers, {
    style: [styles.controlButtonBlock, controlButtonContainerStyle]
  }), /*#__PURE__*/React.createElement(View, {
    style: [styles.controlButton, controlButtonStyle]
  })), children));
};

export { BottomHalfContainer as default };
//# sourceMappingURL=index.container.js.map
