import { isAndroid } from '@lomray/react-native-layout-helper';
import _ from 'lodash';
import { NativeModules, ToastAndroid, BackHandler } from 'react-native';
import ReactNativeHapticFeedback from 'react-native-haptic-feedback';
import { Navigation } from 'react-native-navigation';
import Config from '../../services/config.js';
import customI18n from '../../services/localization.js';

/**
 * Listen back button on android and wait click twice to exit from app.
 * If user can't pop screen.
 *
 * #### (Android specific)
 *
 * NOTE: Wait popScreenDuration and if resetTimer is not called (screen is not popped) then show toast.
 */
var HandleBackButtonAndroid = function HandleBackButtonAndroid() {
  if (!isAndroid) {
    return;
  }
  var hapticOptions = Config.get('hapticFeedbackOptions');
  var popScreenDuration = 400;
  var CommonModule = NativeModules.CommonModule;
  var timerShowToast;
  var timerExitAppWindow;
  var resetTimer = function resetTimer() {
    clearTimeout(timerShowToast);
    clearTimeout(timerExitAppWindow);
    timerShowToast = undefined;
  };
  var backHandler = _.debounce(function () {
    ReactNativeHapticFeedback.trigger('impactMedium', hapticOptions);
    if (timerShowToast) {
      resetTimer();
      CommonModule.minimizeApp();
      return true;
    }
    timerShowToast = setTimeout(function () {
      ToastAndroid.show(customI18n.t('translation:exitApp'), ToastAndroid.SHORT);
      timerExitAppWindow = setTimeout(function () {
        return resetTimer();
      }, 2000); // short toast duration
    }, popScreenDuration);
    return false;
  }, popScreenDuration + 100, {
    leading: true,
    trailing: false
  });
  Navigation.events().registerScreenPoppedListener(resetTimer);
  Navigation.events().registerModalDismissedListener(resetTimer);
  BackHandler.addEventListener('hardwareBackPress', backHandler);
};

export { HandleBackButtonAndroid as default };
//# sourceMappingURL=handler-back-button-android.js.map
