import { createClass as _createClass, classCallCheck as _classCallCheck, defineProperty as _defineProperty, asyncToGenerator as _asyncToGenerator, regeneratorRuntime as _regeneratorRuntime } from '../_virtual/_rollupPluginBabelHelpers.js';
import { Platform } from 'react-native';
import DeviceInfo from 'react-native-device-info';
import Config from './config.js';

/**
 * Check app version from stores
 */
var VersionCheck = /*#__PURE__*/function () {
  /**
   * @constructor
   * @private
   */
  function VersionCheck(options) {
    _classCallCheck(this, VersionCheck);
    /**
     * @private
     */
    _defineProperty(this, "options", void 0);
    /**
     * @private
     */
    _defineProperty(this, "logger", void 0);
    /**
     *  Locale compare returns
     *  0: version strings are equal
     *  1: 1st is greater than 2nd
     * -1: 2nd is greater than 1st
     *
     * To convert to bool, we use returnedValue > 0
     */
    _defineProperty(this, "compareSoftwareVersions", function (firstVersion, secondVersion) {
      if (!firstVersion) {
        return false;
      }
      return firstVersion.localeCompare(secondVersion, undefined, {
        numeric: true,
        sensitivity: 'base'
      }) > 0;
    });
    this.options = options;
    this.logger = Config.get('logger');
  }
  /**
   * Init service
   */
  _createClass(VersionCheck, [{
    key: "getStoreVersion",
    value: (
    /**
     * Get store app version
     */
    function () {
      var _getStoreVersion = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
        var _this$options, bundleId, iosStoreId, countryCode, storeUrl, res, text, match, matchNewLayout, result, _result$results$0$ver, _result$results2, _result$results, _this$logger;
        return _regeneratorRuntime().wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              _this$options = this.options, bundleId = _this$options.bundleId, iosStoreId = _this$options.iosStoreId, countryCode = _this$options.countryCode;
              /**
               * hl stands for 'Host`s language' - language will be used in your app store
               * gl stands for region where application is based in
               */
              storeUrl = Platform.select({
                ios: "https://itunes.apple.com/lookup?bundleId=".concat(bundleId, "&country=").concat(countryCode, "&date=").concat(Date.now()),
                android: "https://play.google.com/store/apps/details?id=".concat(bundleId, "&hl=en&gl=").concat(countryCode.toUpperCase())
              });
              _context.prev = 2;
              _context.next = 5;
              return fetch(storeUrl, {
                headers: {
                  'sec-fetch-site': 'same-origin'
                }
              });
            case 5:
              res = _context.sent;
              if (!(Platform.OS === 'android')) {
                _context.next = 17;
                break;
              }
              _context.next = 9;
              return res.text();
            case 9:
              text = _context.sent;
              match = text.match(/Current Version.+?>([\d.-]+)<\/span>/);
              if (!match) {
                _context.next = 13;
                break;
              }
              return _context.abrupt("return", match[1].trim());
            case 13:
              matchNewLayout = text.match(/\[\[\["([\d.]+?)"\]\]/);
              if (!matchNewLayout) {
                _context.next = 16;
                break;
              }
              return _context.abrupt("return", matchNewLayout[1].trim());
            case 16:
              return _context.abrupt("return", null);
            case 17:
              _context.next = 19;
              return res.json();
            case 19:
              result = _context.sent;
              if (!result.resultCount) {
                _context.next = 23;
                break;
              }
              if (!iosStoreId) {
                this.options.iosStoreId = result === null || result === void 0 || (_result$results = result.results) === null || _result$results === void 0 || (_result$results = _result$results[0]) === null || _result$results === void 0 ? void 0 : _result$results.trackId;
              }
              return _context.abrupt("return", (_result$results$0$ver = result === null || result === void 0 || (_result$results2 = result.results) === null || _result$results2 === void 0 || (_result$results2 = _result$results2[0]) === null || _result$results2 === void 0 ? void 0 : _result$results2.version) !== null && _result$results$0$ver !== void 0 ? _result$results$0$ver : null);
            case 23:
              _context.next = 28;
              break;
            case 25:
              _context.prev = 25;
              _context.t0 = _context["catch"](2);
              (_this$logger = this.logger) === null || _this$logger === void 0 || _this$logger.info('Failed get store version: ', _context.t0);
            case 28:
              return _context.abrupt("return", null);
            case 29:
            case "end":
              return _context.stop();
          }
        }, _callee, this, [[2, 25]]);
      }));
      function getStoreVersion() {
        return _getStoreVersion.apply(this, arguments);
      }
      return getStoreVersion;
    }()
    /**
     * Check if current version is old and need update
     */
    )
  }, {
    key: "needUpdate",
    value: (function () {
      var _needUpdate = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
        var currentVersion, storeVersion;
        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
          while (1) switch (_context2.prev = _context2.next) {
            case 0:
              currentVersion = DeviceInfo.getVersion();
              _context2.next = 3;
              return this.getStoreVersion();
            case 3:
              storeVersion = _context2.sent;
              return _context2.abrupt("return", {
                hasUpdate: this.compareSoftwareVersions(storeVersion, currentVersion),
                storeUrl: this.getStoreUrl()
              });
            case 5:
            case "end":
              return _context2.stop();
          }
        }, _callee2, this);
      }));
      function needUpdate() {
        return _needUpdate.apply(this, arguments);
      }
      return needUpdate;
    }()
    /**
     * Get store url
     */
    )
  }, {
    key: "getStoreUrl",
    value: function getStoreUrl() {
      var _this$options2 = this.options,
        bundleId = _this$options2.bundleId,
        iosStoreId = _this$options2.iosStoreId,
        countryCode = _this$options2.countryCode;
      /**
       * hl stands for 'Host Language' - language will be used in your app store
       * gl stands for region where application is based in
       */
      return Platform.select({
        ios: "itms-apps://apps.apple.com/app/id".concat(iosStoreId),
        android: "https://play.google.com/store/apps/details?id=".concat(bundleId, "&hl=en&gl=").concat(countryCode.toUpperCase())
      });
    }
  }], [{
    key: "init",
    value: function init(options) {
      return new VersionCheck(options);
    }
  }]);
  return VersionCheck;
}();

export { VersionCheck as default };
//# sourceMappingURL=version-check.js.map
