import { defineProperty as _defineProperty, createClass as _createClass, classCallCheck as _classCallCheck, objectSpread2 as _objectSpread2 } from '../../_virtual/_rollupPluginBabelHelpers.js';
import { isIOS } from '@lomray/react-native-layout-helper';
import { makeObservable, observable, computed, action } from 'mobx';
import { AppState } from 'react-native';
import CodePush from 'react-native-code-push';
import DeviceInfo from 'react-native-device-info';
import Config from '../../services/config.js';

/**
 * Application version store
 */
var AppVersionStore = /*#__PURE__*/function () {
  /**
   * @constructor
   */
  function AppVersionStore() {
    var _this = this;
    _classCallCheck(this, AppVersionStore);
    /**
     * Current application version
     */
    _defineProperty(this, "version", DeviceInfo.getVersion());
    /**
     * Current application build number
     */
    _defineProperty(this, "build", DeviceInfo.getBuildNumber());
    /**
     * Codepush version
     *
     * c - codepush build
     * n - native build
     * e - error
     */
    _defineProperty(this, "codepushVersion", '');
    /**
     * Unsubscribe callback
     * @private
     */
    _defineProperty(this, "unsubscribeAppCheck", void 0);
    /**
     * @private
     */
    _defineProperty(this, "logger", void 0);
    /**
     * Add codepush subscribers
     */
    _defineProperty(this, "addSubscribes", function () {
      if (typeof _this.unsubscribeAppCheck === 'function') {
        _this.unsubscribeAppCheck();
      }
      _this.unsubscribeAppCheck = _this.listenCodePush();
    });
    this.logger = Config.get('logger');
    makeObservable(this, {
      version: observable,
      build: observable,
      codepushVersion: observable,
      versionOutput: computed,
      setCodepushVersion: action
    });
    CodePush.getUpdateMetadata().then(function (update) {
      if (update) {
        _this.setCodepushVersion("c-".concat(update.label));
      } else {
        _this.setCodepushVersion('n');
      }
    })["catch"](function () {
      _this.setCodepushVersion('e');
    });
  }
  _createClass(AppVersionStore, [{
    key: "setCodepushVersion",
    value:
    /**
     * Set codepush version
     */
    function setCodepushVersion(version) {
      this.codepushVersion = version;
    }
    /**
     * App version
     */
  }, {
    key: "versionOutput",
    get: function get() {
      var _Config$get;
      var debugPrefix = Config.get('isLocalDevelopment') ? 'd' : '';
      var version = "v".concat(this.version, "(").concat(this.build).concat(debugPrefix, "-").concat(this.codepushVersion, ")");
      (_Config$get = Config.get('logger')) === null || _Config$get === void 0 || _Config$get.setPayload('appVersion', version);
      return version;
    }
    /**
     * Check codepush releases and apply
     * @private
     */
  }, {
    key: "listenCodePush",
    value: function listenCodePush() {
      var _this2 = this;
      var isRealDevice = DeviceInfo.getDeviceType() !== 'unknown' && !DeviceInfo.isEmulatorSync();
      // Disable codepush for simulators
      if (!isRealDevice || Config.get('isLocalDevelopment')) {
        return;
      }
      var keys = Config.get('codepush');
      if (!keys) {
        var _this$logger;
        (_this$logger = this.logger) === null || _this$logger === void 0 || _this$logger.warn('Codepush keys not configure.');
        return;
      }
      var ios = keys.ios,
        android = keys.android;
      var isDev = Config.get('isLocalDevelopment');
      var options = _objectSpread2({}, isDev ? {
        updateDialog: {
          title: 'New cloud update'
        }
      } : {
        installMode: CodePush.InstallMode.IMMEDIATE
      });
      var updateFunc = function updateFunc() {
        void CodePush.sync(_objectSpread2(_objectSpread2({}, options), {}, {
          deploymentKey: isIOS ? ios : android
        })).then(function (res) {
          var _this2$logger;
          (_this2$logger = _this2.logger) === null || _this2$logger === void 0 || _this2$logger.info('App updated: ', res);
        })["catch"](function (e) {
          var _this2$logger2;
          (_this2$logger2 = _this2.logger) === null || _this2$logger2 === void 0 || _this2$logger2.info('App update false: ', e);
        });
      };
      // run first time
      updateFunc();
      // check new release on app state change
      var unsubscribe = AppState.addEventListener('change', function (state) {
        if (state === 'active') {
          updateFunc();
        }
      });
      return function () {
        return unsubscribe.remove();
      };
    }
  }]);
  return AppVersionStore;
}();
/**
 * This is singleton
 */
_defineProperty(AppVersionStore, "isGlobal", true);

export { AppVersionStore as default };
//# sourceMappingURL=index.js.map
