import { createClass as _createClass, classCallCheck as _classCallCheck, defineProperty as _defineProperty, toConsumableArray as _toConsumableArray, asyncToGenerator as _asyncToGenerator, regeneratorRuntime as _regeneratorRuntime } from '../../_virtual/_rollupPluginBabelHelpers.js';
import wait from '@lomray/client-helpers/helpers/wait';
import _ from 'lodash';
import { makeObservable, observable, action, runInAction } from 'mobx';

/**
 * Flat list store
 */
var FlatListStore = /*#__PURE__*/function () {
  /**
   * @constructor
   */
  function FlatListStore(store, _ref) {
    var _this = this;
    var method = _ref.method,
      entities = _ref.entities,
      _ref$firstDelay = _ref.firstDelay,
      firstDelay = _ref$firstDelay === void 0 ? 0 : _ref$firstDelay,
      _ref$totalEntities = _ref.totalEntities,
      totalEntities = _ref$totalEntities === void 0 ? 0 : _ref$totalEntities,
      _ref$initPage = _ref.initPage,
      initPage = _ref$initPage === void 0 ? 1 : _ref$initPage,
      _ref$pageSize = _ref.pageSize,
      pageSize = _ref$pageSize === void 0 ? 10 : _ref$pageSize,
      keyName = _ref.keyName;
    _classCallCheck(this, FlatListStore);
    /**
     * List of entities
     */
    _defineProperty(this, "entities", []);
    /**
     * Indicates than API request in process
     */
    _defineProperty(this, "isFetching", false);
    /**
     * Indicates than flat list renders first time
     */
    _defineProperty(this, "isFirstRender", true);
    /**
     * Total entities count
     */
    _defineProperty(this, "totalEntities", 0);
    /**
     * Current page
     */
    _defineProperty(this, "currentPage", 1);
    /**
     * Default page size
     */
    _defineProperty(this, "pageSize", 10);
    /**
     * Key extractor property name
     */
    _defineProperty(this, "keyName", void 0);
    /**
     * Delay first request to prevent flickering
     */
    _defineProperty(this, "firstDelay", void 0);
    /**
     * Get flat list entities method
     */
    _defineProperty(this, "method", void 0);
    /**
     * @private
     */
    _defineProperty(this, "store", void 0);
    /**
     * Get entities
     */
    _defineProperty(this, "getEntities", function () {
      var page = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 1;
      return (
        // @ts-ignore
        _this.store[_this.method](page)
      );
    });
    /**
     * Extract key from entity for flat list
     */
    _defineProperty(this, "keyExtractor", function (entity) {
      return String(entity[_this.keyName]);
    });
    // @ts-ignore
    store[method] = this.wrapRequest(store[method]);
    this.store = store;
    this.method = method;
    this.entities = entities !== null && entities !== void 0 ? entities : [];
    this.totalEntities = totalEntities;
    this.currentPage = initPage;
    this.pageSize = pageSize;
    // @ts-ignore
    this.keyName = keyName || 'id';
    this.firstDelay = firstDelay;
    makeObservable(this, {
      entities: observable,
      totalEntities: observable,
      isFetching: observable,
      pageSize: observable,
      isFirstRender: observable,
      setEntities: action.bound,
      getNextPage: action.bound,
      setFetching: action.bound,
      setTotalCountEntities: action.bound,
      resetIsFirstRender: action.bound
    });
  }
  /**
   * Reset state before retry requests
   */
  _createClass(FlatListStore, [{
    key: "resetIsFirstRender",
    value: function resetIsFirstRender() {
      this.isFirstRender = true;
    }
    /**
     * Set flat list entities
     */
  }, {
    key: "setEntities",
    value: function setEntities(entities) {
      var shouldAdd = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
      if (shouldAdd) {
        this.entities = _.uniqBy([].concat(_toConsumableArray(this.entities), _toConsumableArray(entities)), this.keyName);
      } else {
        this.entities = entities;
      }
    }
  }, {
    key: "wrapRequest",
    value:
    /**
     * Wrapper for get entities
     */
    function wrapRequest(callback) {
      var _this2 = this;
      return /*#__PURE__*/function () {
        var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(pageVal) {
          var startTime, result;
          return _regeneratorRuntime().wrap(function _callee$(_context) {
            while (1) switch (_context.prev = _context.next) {
              case 0:
                _this2.setFetching(true);
                startTime = Date.now();
                _context.next = 4;
                return callback(pageVal);
              case 4:
                result = _context.sent;
                if (!(_this2.firstDelay && Date.now() - startTime < _this2.firstDelay)) {
                  _context.next = 8;
                  break;
                }
                _context.next = 8;
                return wait(_this2.firstDelay);
              case 8:
                runInAction(function () {
                  _this2.setFetching(false);
                  if (result === undefined) {
                    return;
                  }
                  var list = result.list,
                    count = result.count,
                    page = result.page;
                  _this2.currentPage = page;
                  _this2.setTotalCountEntities(count);
                  _this2.setEntities(list, page > 1);
                });
                return _context.abrupt("return", result);
              case 10:
              case "end":
                return _context.stop();
            }
          }, _callee);
        }));
        return function (_x) {
          return _ref2.apply(this, arguments);
        };
      }();
    }
    /**
     * Toggle fetching
     */
  }, {
    key: "setFetching",
    value: function setFetching(isFetching) {
      this.isFetching = isFetching;
      if (!this.isFetching) {
        this.isFirstRender = false;
      }
    }
  }, {
    key: "getNextPage",
    value:
    /**
     * Lazy load pagination
     */
    function getNextPage() {
      if (this.currentPage * this.pageSize >= this.totalEntities) {
        return;
      }
      if (this.entities.length >= this.totalEntities) {
        return;
      }
      if (this.currentPage === 1 && this.totalEntities < this.pageSize) {
        return;
      }
      return this.getEntities(this.currentPage + 1);
    }
    /**
     * Set count entities
     */
  }, {
    key: "setTotalCountEntities",
    value: function setTotalCountEntities(count) {
      this.totalEntities = count;
    }
  }]);
  return FlatListStore;
}();

export { FlatListStore as default };
//# sourceMappingURL=index.js.map
